@@ -14,7 +14,7 @@ class Seeder(metaclass=ABCMeta):
         self.env = options.env
 
     @classmethod
-    def add_parser_arguments(cls, parser, interpreter, app_data):
+    def add_parser_arguments(cls, parser, interpreter, app_data):  # noqa: U100
         """
         Add CLI arguments for this seed mechanisms.
 
